function [MVAbase, bus, gen, branch, success, et] = runpf(casename, mpopt, fname)
%
%   [baseMVA, bus, gen, branch, success, et] = runpf(casename, mpopt, fname)
%   Metodo completo di Newton per il calcolo dei flussi di potenza
%   "casename"  il nome del file .m che contiene le informazioni relative
%   all'impianto, e mpopt  un vettore MATPOWER opzionale (vedi help
%   mpoption per i dettagli).
%   La funzione di calcolo usa i valori di default nel caso in cui non
%   siano impostate le opzioni 2 e 3 (ovvero:mpopt, fname), mentre usa
%   il file 'case.m' nel caso in cui non venga specificato il file dei
%   dati.
%   I risultati del calcolo possono essere o meno stampati in un file
%   (concatenando i risultati se il file esiste gi) il cui nome 
%   indicato nell'opzione "fname".

%   MATPOWER Version 2.0
%   by Ray Zimmerman, PSERC Cornell    12/24/97
%   Copyright (c) 1996, 1997 by Power System Engineering Research Center (PSERC)
%   See http://www.pserc.cornell.edu/ for more info.
tic;
%% define named indices into bus, gen, branch matrices
[PQ, PV, REF, NONE, BUS_I, BUS_TYPE, PD, QD, GS, BS, BUS_AREA, VM, ...
        VA, BASE_KV, ZONE, VMAX, VMIN, LAM_P, LAM_Q, MU_VMAX, MU_VMIN] = idx_bus;
[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, ...
        GEN_STATUS, PMAX, PMIN, MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN] = idx_gen;

%% default arguments
if nargin < 3
        fname = '';                                     %% don't print results to a file
        if nargin < 2
                mpopt = mpoption;               %% use default options
                if nargin < 1
                        casename = 'case';      %% default data file is 'case.m'
                end
        end
end

%% options
alg = mpopt(1);

%% read data & convert to internal bus numbering
[baseMVA, bus, gen, branch] = feval(casename);
[i2e, bus, gen, branch] = ext2int(bus, gen, branch);

%% get bus index lists of each type of bus
[ref, pv, pq] = bustypes(bus, gen);

%% build admittance matrices
[Ybus, Yf, Yt] = makeYbus(baseMVA, bus, branch);

%% compute complex bus power injections (generation - load)
Sbus = makeSbus(baseMVA, bus, gen);

%% generator info
on = find(gen(:, GEN_STATUS));                          %% which generators are on?

%% initialize V and Pg from data from case file
% V0    = ones(size(bus, 1), 1);                %% flat start
V0      = bus(:, VM) .* exp(sqrt(-1) * pi/180 * bus(:, VA));
V0(gen(on, GEN_BUS)) = gen(on, VG) ./ abs(V0(gen(on, GEN_BUS))).* V0(gen(on, GEN_BUS));

%% run the power flow
t0 = clock;
if alg == 1
        [V, success, iterations] = newtonpf(Ybus, Sbus, V0, ref, pv, pq, mpopt);
elseif alg == 2 | alg == 3
        [Bp, Bpp] = makeB(baseMVA, bus, branch, alg);
        [V, success, iterations] = fdpf(Ybus, Sbus, V0, Bp, Bpp, ref, pv, pq, mpopt);
elseif alg ==4
        [V, success, iterations] = glimmpf(Ybus, Sbus, V0, ref, pv, pq, mpopt);
else
        error('Only Newton''s method , fast-decoupled power flow and Glimm & Stagg algorithms currently implemented.');
end

%% compute flows etc.
[bus, gen, branch] = pfsoln(baseMVA, bus, gen, branch, Ybus, Yf, Yt, V, ref, pv, pq);
et = etime(clock, t0);

%% convert back to original bus numbering & print results
[bus, gen, branch] = int2ext(i2e, bus, gen, branch);
if fname
        [fd, msg] = fopen(fname, 'at');
        if fd == -1
                error(msg);
        else
                printpf(baseMVA, bus, gen, branch, [], success, et, fd, mpopt);
                fclose(fd);
        end
end
Ybus
printpf(baseMVA, bus, gen, branch, [], success, et, 1, mpopt);

%% this is just to prevent it from printing baseMVA
%% when called with no output arguments
if nargout, MVAbase = baseMVA; end

return;
